OptimizationConfig

Struct OptimizationConfig 

pub struct OptimizationConfig {
    pub target_partitions: usize,
    pub enable_optimizer: bool,
    pub enable_predicate_pushdown: bool,
    pub enable_projection_pushdown: bool,
    pub enable_parquet_pushdown: bool,
    pub batch_size: usize,
    pub enable_query_cache: bool,
    pub max_cache_entries: usize,
    pub memory_limit: Option<usize>,
}
Configuration for query optimization

Fields

target_partitions: usize

Target number of partitions for parallel query execution Higher values enable more parallelism but increase overhead Default: number of CPU cores

enable_optimizer: bool

Enable/disable query optimization Default: true

enable_predicate_pushdown: bool

Enable/disable predicate pushdown optimization Pushes filters as early as possible in the query plan Default: true

enable_projection_pushdown: bool

Enable/disable projection pushdown optimization Only reads columns that are actually needed Default: true

enable_parquet_pushdown: bool

Enable/disable filter pushdown to Parquet readers Uses Parquet row group statistics to skip reading unnecessary data Default: true

batch_size: usize

Batch size for query execution Larger batches improve throughput but use more memory Default: 8192

enable_query_cache: bool

Enable query result caching Default: true

max_cache_entries: usize

Maximum number of cached query results Default: 100

memory_limit: Option<usize>

Memory limit for query execution (in bytes) None means unlimited Default: None

Implementations

Source

impl OptimizationConfig

pub fn new() -> Self

Create a new optimization configuration with default settings

pub fn with_target_partitions(self, partitions: usize) -> Self

Set target partitions for parallel execution

pub fn with_batch_size(self, size: usize) -> Self

Set batch size for query execution

pub fn with_predicate_pushdown(self, enabled: bool) -> Self

Enable or disable predicate pushdown

pub fn with_projection_pushdown(self, enabled: bool) -> Self

Enable or disable projection pushdown

pub fn with_parquet_pushdown(self, enabled: bool) -> Self

Enable or disable Parquet pushdown optimizations

pub fn with_memory_limit(self, limit: usize) -> Self

Set memory limit for query execution

pub fn with_query_cache(self, enabled: bool) -> Self

Enable or disable query result caching

pub fn with_max_cache_entries(self, max: usize) -> Self

Set maximum number of cached query results

pub fn to_session_config(&self) -> SessionConfig

Create a DataFusion SessionConfig from this optimization config

pub fn to_runtime_env(&self) -> Arc<RuntimeEnv>

Create a DataFusion RuntimeEnv from this optimization config